==> MacOSX10.12.sdk.zip: MacOSX10.12.sdk/System/Library/Frameworks/CoreData.framework/Versions/A/Headers/CoreData.h <==
/*
	CoreData.h
	Core Data
    Copyright (c) 2004-2016, Apple Inc.
	All rights reserved.
*/

#import <Foundation/Foundation.h>

#import <CoreData/CoreDataDefines.h>
#import <CoreData/CoreDataErrors.h>

#import <CoreData/NSAttributeDescription.h>
#import <CoreData/NSEntityDescription.h>
#import <CoreData/NSFetchedPropertyDescription.h>
#import <CoreData/NSPropertyDescription.h>
#import <CoreData/NSExpressionDescription.h>
#import <CoreData/NSRelationshipDescription.h>
#import <CoreData/NSFetchRequest.h>
#import <CoreData/NSFetchRequestExpression.h>
#import <CoreData/NSManagedObjectModel.h>

#import <CoreData/NSManagedObject.h>
#import <CoreData/NSManagedObjectID.h>
#import <CoreData/NSManagedObjectContext.h>
#import <CoreData/NSPersistentStoreCoordinator.h>

#import <CoreData/NSPersistentStore.h>
#import <CoreData/NSAtomicStore.h>
#import <CoreData/NSAtomicStoreCacheNode.h>

#import <CoreData/NSEntityMigrationPolicy.h>
#import <CoreData/NSMappingModel.h>
#import <CoreData/NSEntityMapping.h>
#import <CoreData/NSPropertyMapping.h>
#import <CoreData/NSMigrationManager.h>

#import <CoreData/NSIncrementalStore.h>
#import <CoreData/NSIncrementalStoreNode.h>

#import <CoreData/NSPersistentStoreRequest.h>
#import <CoreData/NSPersistentStoreResult.h>
#import <CoreData/NSSaveChangesRequest.h>
#import <CoreData/NSBatchUpdateRequest.h>
#import <CoreData/NSBatchDeleteRequest.h>

#import <CoreData/NSMergePolicy.h>

#import <CoreData/NSFetchedResultsController.h>
#import <CoreData/NSQueryGenerationToken.h>
#import <CoreData/NSPersistentStoreDescription.h>
#import <CoreData/NSPersistentContainer.h>

==> MacOSX10.13.sdk.zip: MacOSX10.13.sdk/System/Library/Frameworks/CoreData.framework/Versions/A/Headers/CoreData.h <==
/*
    CoreData.h
    Core Data
    Copyright (c) 2004-2017, Apple Inc.
    All rights reserved.
*/

#import <Foundation/Foundation.h>

#import <CoreData/CoreDataDefines.h>
#import <CoreData/CoreDataErrors.h>

#import <CoreData/NSAttributeDescription.h>
#import <CoreData/NSEntityDescription.h>
#import <CoreData/NSFetchedPropertyDescription.h>
#import <CoreData/NSPropertyDescription.h>
#import <CoreData/NSExpressionDescription.h>
#import <CoreData/NSRelationshipDescription.h>
#import <CoreData/NSFetchIndexDescription.h>
#import <CoreData/NSFetchIndexElementDescription.h>
#import <CoreData/NSFetchRequest.h>
#import <CoreData/NSFetchRequestExpression.h>
#import <CoreData/NSManagedObjectModel.h>

#import <CoreData/NSManagedObject.h>
#import <CoreData/NSManagedObjectID.h>
#import <CoreData/NSManagedObjectContext.h>
#import <CoreData/NSPersistentStoreCoordinator.h>

#import <CoreData/NSPersistentStore.h>
#import <CoreData/NSAtomicStore.h>
#import <CoreData/NSAtomicStoreCacheNode.h>

#import <CoreData/NSEntityMigrationPolicy.h>
#import <CoreData/NSMappingModel.h>
#import <CoreData/NSEntityMapping.h>
#import <CoreData/NSPropertyMapping.h>
#import <CoreData/NSMigrationManager.h>

#import <CoreData/NSIncrementalStore.h>
#import <CoreData/NSIncrementalStoreNode.h>

#import <CoreData/NSPersistentStoreRequest.h>
#import <CoreData/NSPersistentStoreResult.h>
#import <CoreData/NSSaveChangesRequest.h>
#import <CoreData/NSBatchUpdateRequest.h>
#import <CoreData/NSBatchDeleteRequest.h>

#import <CoreData/NSMergePolicy.h>

#import <CoreData/NSFetchedResultsController.h>
#import <CoreData/NSQueryGenerationToken.h>
#import <CoreData/NSPersistentStoreDescription.h>
#import <CoreData/NSPersistentContainer.h>

#import <CoreData/NSFetchIndexDescription.h>
#import <CoreData/NSFetchIndexElementDescription.h>
#import <CoreData/NSPersistentHistoryChange.h>
#import <CoreData/NSPersistentHistoryChangeRequest.h>
#import <CoreData/NSPersistentHistoryToken.h>
#import <CoreData/NSPersistentHistoryTransaction.h>

#import <CoreData/NSCoreDataCoreSpotlightDelegate.h>
